import { now } from "../utils/time";
export class TaskManager {
    constructor(planningType, plannedTasksStore, foregroundChecker, intervalOffset, currentTime = now()) {
        this.planningType = planningType;
        this.plannedTasksStore = plannedTasksStore;
        this.foregroundChecker = foregroundChecker;
        this.intervalOffset = intervalOffset;
        this.currentTime = currentTime;
    }
    async tasksToRun() {
        const allTasks = await this.allTasks();
        return allTasks.filter((task) => this.determineIfTaskShouldBeRun(task));
    }
    async requiresForeground() {
        const tasksToRun = await this.tasksToRun();
        for (let task of tasksToRun) {
            const requiresForeground = this.foregroundChecker.requiresForegroundThroughChain(task.name);
            if (requiresForeground) {
                return true;
            }
        }
        return false;
    }
    async willContinue() {
        return (await this.nextInterval()) !== -1;
    }
    async nextInterval() {
        const allTasks = await this.allTasks();
        if (allTasks.length === 0) {
            return -1;
        }
        const tasksToRunInTheFuture = allTasks.filter((task) => task.recurrent || !this.determineIfTaskShouldBeRun(task));
        if (tasksToRunInTheFuture.length === 0) {
            return -1;
        }
        const nextIntervals = tasksToRunInTheFuture.map((task) => {
            let next = task.nextRun(this.currentTime);
            if (next < this.intervalOffset) {
                next += task.interval;
            }
            return next;
        });
        const sortedIntervals = nextIntervals.sort((i1, i2) => i1 - i2);
        return sortedIntervals[0];
    }
    determineIfTaskShouldBeRun(task) {
        if (this.currentTime < task.startAt - this.intervalOffset) {
            return false;
        }
        else if (task.lastUpdate < task.startAt) {
            return true;
        }
        return (this.currentTime >= task.lastUpdate + task.interval - this.intervalOffset);
    }
    async allTasks() {
        if (!this._allTasks) {
            this._allTasks = await this.plannedTasksStore.getAllSortedByNextRun(this.planningType);
        }
        return this._allTasks;
    }
}
//# sourceMappingURL=manager.js.map