import { uuid } from "../../utils/uuid";
import { now } from "../../utils/time";
export var PlanningType;
(function (PlanningType) {
    PlanningType["Scheduled"] = "scheduled";
    PlanningType["Immediate"] = "immediate";
})(PlanningType || (PlanningType = {}));
export var SchedulerType;
(function (SchedulerType) {
    SchedulerType["None"] = "none";
    SchedulerType["Alarm"] = "alarm";
})(SchedulerType || (SchedulerType = {}));
export class PlannedTask {
    constructor(planningType, schedulerType, task, id = uuid(), createdAt = now(), lastRun = -1, errorCount = 0, timeoutCount = 0) {
        this.planningType = planningType;
        this.schedulerType = schedulerType;
        this.id = id;
        this.createdAt = createdAt;
        this.lastRun = lastRun;
        this.errorCount = errorCount;
        this.timeoutCount = timeoutCount;
        this.name = task.name;
        this.startAt = task.startAt;
        this.interval = task.interval;
        this.recurrent = task.recurrent;
        this.params = task.params;
        this.cancelEvent = task.cancelEvent;
    }
    get lastUpdate() {
        return this.lastRun !== -1 ? this.lastRun : this.createdAt;
    }
    nextRun(currentTime = now()) {
        if (this.startAt !== -1 && currentTime < this.startAt) {
            return this.startAt - currentTime;
        }
        return this.interval - (currentTime - this.lastUpdate);
    }
}
//# sourceMappingURL=planned-task.js.map