import { TaskDispatcherEvent, } from "../../events";
import { toSeconds } from "../../utils/time-converter";
import { getLogger } from "../../utils/logger";
export class RunnableTaskBuilderImpl {
    constructor(taskName, params, taskPlanner) {
        this.taskName = taskName;
        this.params = params;
        this.taskPlanner = taskPlanner;
        this.startAt = -1;
        this.interval = 0;
        this.recurrent = false;
        this.cancelEvent = TaskDispatcherEvent.DefaultCancelEvent;
        this.logger = getLogger("RunnableTaskBuilder");
    }
    now() {
        this.startAt = -1;
        this.interval = 0;
        this.recurrent = false;
        return this;
    }
    every(time, timeUnit) {
        const seconds = timeUnit ? toSeconds(time, timeUnit) : time;
        this.interval = seconds;
        this.recurrent = true;
        return this;
    }
    in(time, timeUnit) {
        const seconds = timeUnit ? toSeconds(time, timeUnit) : time;
        this.interval = seconds;
        this.recurrent = false;
        return this;
    }
    at(date) {
        if (date > new Date()) {
            this.startAt = date.getTime();
        }
        this.recurrent = false;
        return this;
    }
    cancelOn(eventName) {
        this.cancelEvent = eventName;
        return this;
    }
    build() {
        return {
            name: this.taskName,
            startAt: this.startAt,
            interval: this.interval,
            recurrent: this.recurrent,
            cancelEvent: this.cancelEvent,
            params: this.params,
        };
    }
    async plan(dispatchableEvent) {
        const runnableTask = this.build();
        try {
            return this.taskPlanner.plan(runnableTask, dispatchableEvent);
        }
        catch (err) {
            throw new Error(`Could not plan (${JSON.stringify(runnableTask)}). Reason: ${err}`);
        }
    }
    onReceive(dispatchableEvent) {
        this.plan(dispatchableEvent)
            .then((plannedTask) => {
            this.logger.info(`Task planned: ${JSON.stringify(plannedTask)}`);
        })
            .catch((err) => {
            this.logger.error(err);
        });
    }
}
//# sourceMappingURL=builder.js.map