import { on, TaskDispatcherEvent, off, createEvent, emit, } from "../../events";
import { SingleTaskRunner } from "./single-task-runner";
import { getLogger } from "../../utils/logger";
export class BatchTaskRunner {
    constructor(taskStore) {
        this.taskRunner = new SingleTaskRunner(taskStore);
        this.logger = getLogger("BatchTaskRunner");
    }
    async run(plannedTasks, startEvent) {
        await Promise.all(plannedTasks.map((plannedTask) => this.runTaskWithCustomStartEvent(plannedTask, startEvent)));
    }
    runTaskWithCustomStartEvent(plannedTask, batchStartEvent) {
        const startEvent = createEvent(TaskDispatcherEvent.TaskExecutionStarted, {
            expirationTimestamp: batchStartEvent.expirationTimestamp,
        });
        const listenerId = on(TaskDispatcherEvent.TaskExecutionTimedOut, (evt) => {
            if (evt.id === batchStartEvent.id) {
                off(TaskDispatcherEvent.TaskExecutionTimedOut, listenerId);
                emit(createEvent(TaskDispatcherEvent.TaskExecutionTimedOut, {
                    id: startEvent.id,
                }));
            }
        });
        this.logger.info(`Child event (name=${startEvent.name}, id=${startEvent.id}) spawned (invocationId=${batchStartEvent.id})`);
        return this.taskRunner.run(plannedTask, startEvent);
    }
}
//# sourceMappingURL=batch-task-runner.js.map