import { TaskManager } from "../../../../../manager";
import { AndroidAlarmManager } from "./manager.android";
import { plannedTasksDB } from "../../../../../../persistence/planned-tasks-store";
import { ForegroundChecker } from "../../../../../foreground-checker";
import { createAlarmRunnerServiceIntent } from "../../intents.android";
import { PlanningType } from "../../../../../planner/planned-task";
import { getLogger } from "../../../../../../utils/logger";
import { now } from "../../../../../../utils/time";
import { lastRecurrentRun } from "../../../../../runners/last-recurrent-run";
const MIN_INTERVAL = 59000;
export class AlarmReceiver {
    onReceive(context, intent) {
        lastRecurrentRun.updateLast();
        this.logger = getLogger("AlarmReceiver");
        this.logger.info("Alarm triggered");
        this.timeOffset = 30000;
        this.currentTime = now();
        this.taskManager = new TaskManager(PlanningType.Scheduled, plannedTasksDB, new ForegroundChecker(), this.timeOffset, this.currentTime);
        this.alarmManager = new AndroidAlarmManager();
        this.handleAlarmTrigger(context)
            .then(() => {
            this.logger.debug("Alarm handled");
        })
            .catch((err) => {
            this.logger.error(err);
        });
    }
    async handleAlarmTrigger(context) {
        await this.rescheduleIfNeeded();
        await this.startTaskRunnerService(context);
    }
    async rescheduleIfNeeded() {
        const willContinue = await this.taskManager.willContinue();
        if (willContinue) {
            let nextInterval = await this.taskManager.nextInterval();
            nextInterval = nextInterval > MIN_INTERVAL ? nextInterval : MIN_INTERVAL;
            this.alarmManager.set(nextInterval);
            this.logger.info(`Next alarm will be run in: ${nextInterval}`);
        }
        else {
            this.logger.info("Won't reschedule");
        }
    }
    async startTaskRunnerService(context) {
        const tasksToRun = await this.taskManager.tasksToRun();
        if (tasksToRun.length > 0) {
            const requiresForeground = await this.taskManager.requiresForeground();
            this.startAlarmRunnerService(context, requiresForeground);
        }
        else {
            this.logger.warn("Alarm triggered without tasks to run!");
        }
    }
    startAlarmRunnerService(context, inForeground) {
        const startRunnerService = createAlarmRunnerServiceIntent(context, {
            runInForeground: inForeground,
            timeOffset: this.timeOffset,
            invocationTime: this.currentTime,
        });
        if (inForeground) {
            androidx.core.content.ContextCompat.startForegroundService(context, startRunnerService);
        }
        else {
            context.startService(startRunnerService);
        }
    }
}
let _alarmReceiver;
export function getAlarmReceiver() {
    if (!_alarmReceiver) {
        _alarmReceiver = new AlarmReceiver();
    }
    return _alarmReceiver;
}
//# sourceMappingURL=receiver.android.js.map