import { Application } from "@nativescript/core";
import { createSavingsDeactivationIntent } from "../intents.android";
import { getLogger } from "../../../../../utils/logger";
export class PowerSavingsManager {
    constructor(powerManager = Application.android.context.getSystemService(android.content.Context.POWER_SERVICE), skdVersion = android.os.Build.VERSION.SDK_INT) {
        this.powerManager = powerManager;
        this.skdVersion = skdVersion;
        this.logger = getLogger("PowerSavingsManager");
        this.appPackage = Application.android.context.getPackageName();
    }
    requestDeactivation() {
        if (this.askedOnce || this.areDisabled()) {
            return;
        }
        if (!Application.android.foregroundActivity) {
            this.logger.warn("Battery savings can not be enabled in background");
            return;
        }
        this.askedOnce = true;
        const intent = createSavingsDeactivationIntent(this.appPackage);
        Application.android.foregroundActivity.startActivity(intent);
    }
    areDisabled() {
        if (this.skdVersion < 23) {
            return true;
        }
        return this.powerManager.isIgnoringBatteryOptimizations(this.appPackage);
    }
}
let powerSavingsManager;
export function getPowerSavingsManager() {
    if (!powerSavingsManager) {
        powerSavingsManager = new PowerSavingsManager();
    }
    return powerSavingsManager;
}
//# sourceMappingURL=power-savings-manager.android.js.map