import { PlanningType } from "../../../planner/planned-task";
import { AndroidAlarmScheduler } from "./alarms/alarm/scheduler.android";
import { plannedTasksDB, } from "../../../../persistence/planned-tasks-store";
import { checkIfTaskExists } from "../../../provider";
import { toSeconds } from "../../../../utils/time-converter";
export class AndroidTaskScheduler {
    constructor(alarmScheduler = new AndroidAlarmScheduler(), tasksStore = plannedTasksDB) {
        this.alarmScheduler = alarmScheduler;
        this.tasksStore = tasksStore;
    }
    setup() {
        this.alarmScheduler.setup();
    }
    async schedule(task) {
        checkIfTaskExists(task.name);
        const time = task.interval;
        const taskToSchedule = Object.assign(Object.assign({}, task), { interval: time * 1000 });
        if (time < 1) {
            throw new Error(`Scheduled tasks cannot run in less than 1 second intervals. Use an immediate task instead.

        Keep in mind that recurrent immediate tasks are hard to implement and strongly discouraged.`);
        }
        if (time >= 1 && time < toSeconds(1, "minutes")) {
            throw new Error(`Running tasks with intervals ranging from 1 to 60 seconds is a foreseen feature and will be implemented in the future.

        Keep in mind that executing this kind of tasks in a sustained way will drain system resources. Use them responsibly.`);
        }
        else {
            return this.alarmScheduler.schedule(taskToSchedule);
        }
    }
    async cancel(plannedTaskId) {
        const task = await this.tasksStore.get(plannedTaskId);
        switch (task.planningType) {
            case PlanningType.Scheduled:
                return this.alarmScheduler.cancel(plannedTaskId);
            default:
                throw new Error("Method not implemented.");
        }
    }
}
let _androidTaskScheduler;
export function getAndroidTaskScheduler() {
    if (!_androidTaskScheduler) {
        _androidTaskScheduler = new AndroidTaskScheduler();
    }
    return _androidTaskScheduler;
}
//# sourceMappingURL=index.js.map